@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
-from fast_tracker.admin import command, usage
+from fast_tracker.admin import command
 
 
 @command('validate-config', 'config_file [log_file]',
