@@ -7,13 +7,9 @@ import sys
 import time
 import threading
 import logging
-import itertools
 import random
-import warnings
 import weakref
 
-from collections import deque
-
 import fast_tracker.packages.six as six
 
 import fast_tracker.core.transaction_node
@@ -33,13 +29,11 @@ from fast_tracker.core.attribute_filter import (DST_NONE, DST_ERROR_COLLECTOR,
 from fast_tracker.core.config import DEFAULT_RESERVOIR_SIZE
 from fast_tracker.core.custom_event import create_custom_event
 from fast_tracker.core.stack_trace import exception_stack
-from fast_tracker.common.encoding_utils import (generate_path_hash, obfuscate,
-                                                deobfuscate, json_encode, json_decode, base64_decode,
+from fast_tracker.common.encoding_utils import (generate_path_hash,
                                                 convert_to_cat_metadata_value, DistributedTracePayload, ensure_str,
                                                 W3CTraceParent, W3CTraceState, NrTraceState)
-from fast_tracker.common.utils import seq_id
+from fast_tracker.common.span_enum import SpanType, SpanLayerAtrr
 
-from fast_tracker.api.settings import STRIP_EXCEPTION_MESSAGE
 from fast_tracker.api.time_trace import TimeTrace
 
 _logger = logging.getLogger(__name__)
@@ -209,8 +203,8 @@ class Transaction(object):
 
         self.rum_token = None
 
-        trace_id = seq_id() # TODO trace_id的入口
-        self.guid = ('%032x' % random.getrandbits(128))[:16]
+        trace_id = ''  # TODO trace_id的入口
+        self.guid = ''
         self._trace_id = trace_id
 
         self.parent_type = None
@@ -350,6 +344,8 @@ class Transaction(object):
             path=self.path,
             trusted_parent_span=self.trusted_parent_span,
             tracing_vendors=self.tracing_vendors,
+            span_type=SpanType.Entry.value,
+            span_layer=SpanLayerAtrr.HTTP.value
         )
 
         self.total_time += exclusive
@@ -374,7 +370,6 @@ class Transaction(object):
                                           (framework, version), 1)
 
         if self._settings.distributed_tracing.enabled:
-
             self._compute_sampled_and_priority()
 
         self._cached_path._name = self.path
@@ -432,12 +427,13 @@ class Transaction(object):
             trace_id=self.trace_id,
             loop_time=self._loop_time,
             root=root_node,
+            thread_id=self.thread_id
         )
         self._settings = None
         self.enabled = False
         if not self.ignore_transaction:
             self._application.record_transaction(node)
-            
+
     @property
     def sampled(self):
         return self._sampled
@@ -694,7 +690,6 @@ class Transaction(object):
         return create_user_attributes(self._custom_params,
                                       self.attribute_filter)
 
-
     def _compute_sampled_and_priority(self):
         if self._priority is None:
             self._priority = float('%.6f' % random.random())
@@ -842,18 +837,17 @@ class Transaction(object):
             if major_version is None:
                 return False
 
-            if major_version > DistributedTracePayload.version[0]:  
+            if major_version > DistributedTracePayload.version[0]:
                 return False
 
             data = payload.get('d', {})
-            if not all(k in data for k in DISTRIBUTED_TRACE_KEYS_REQUIRED):             
+            if not all(k in data for k in DISTRIBUTED_TRACE_KEYS_REQUIRED):
                 return False
 
             # Must have either id or tx
             if not any(k in data for k in ('id', 'tx')):
                 return False
 
-            settings = self._settings
             try:
                 data['ti'] = int(data['ti'])
             except:
@@ -914,7 +908,7 @@ class Transaction(object):
         try:
             traceparent = headers.get('traceparent', '')
             tracestate = headers.get('tracestate', '')
-            distributed_header = headers.get('fast', '')
+            distributed_header = headers.get('fast-tracker', '')
         except Exception:
             traceparent = ''
             tracestate = ''
@@ -926,7 +920,7 @@ class Transaction(object):
                     traceparent = v
                 elif k == 'tracestate':
                     tracestate = v
-                elif k == 'fast':
+                elif k == 'fast-tracker':
                     distributed_header = v
 
         if traceparent:
@@ -969,91 +963,28 @@ class Transaction(object):
 
     def _process_incoming_cat_headers(self, encoded_cross_process_id,
                                       encoded_txn_header):
-        settings = self._settings
-
-        if not self.enabled:
-            return
-
-        if not (settings.cross_application_tracer.enabled and
-                settings.cross_process_id and settings.encoding_key):
-            return
-
-        if encoded_cross_process_id is None:
-            return
-
-        try:
-            client_cross_process_id = deobfuscate(
-                encoded_cross_process_id, settings.encoding_key)
-            client_account_id, client_application_id = \
-                map(int, client_cross_process_id.split('#'))
-            self.client_cross_process_id = client_cross_process_id
-            self.client_account_id = client_account_id
-            self.client_application_id = client_application_id
-
-            txn_header = json_decode(deobfuscate(
-                encoded_txn_header,
-                settings.encoding_key))
-
-            if txn_header:
-                self.is_part_of_cat = True
-                self.referring_transaction_guid = txn_header[0]
-
-                self.record_tt = (self.record_tt or
-                                  txn_header[1])
-
-                if isinstance(txn_header[2], six.string_types):
-                    self._trip_id = txn_header[2]
-                if isinstance(txn_header[3], six.string_types):
-                    self._referring_path_hash = txn_header[3]
-        except Exception:
-            pass
+        """
+        不支持跨应用监控
+        :param encoded_cross_process_id:
+        :param encoded_txn_header:
+        :return:
+        """
+        pass
 
     def _generate_response_headers(self, read_length=None):
-        nr_headers = []
+        """
 
-        if self.client_cross_process_id is not None:
-
-            if self.queue_start:
-                queue_time = self.start_time - self.queue_start
-            else:
-                queue_time = 0
-
-            if self.end_time:
-                duration = self.end_time - self.start_time
-            else:
-                duration = time.time() - self.start_time
-
-            self._freeze_path()
-
-            if read_length is None:
-                read_length = self._read_length
-
-            read_length = read_length if read_length is not None else -1
-
-            payload = (self._settings.cross_process_id, self.path, queue_time,
-                       duration, read_length, self.guid, self.record_tt)
-            app_data = json_encode(payload)
-
-            nr_headers.append(('X-fast-App-Data', obfuscate(
-                app_data, self._settings.encoding_key)))
-
-        return nr_headers
+        :param read_length:
+        :return:
+        """
+        return []
 
     def get_response_metadata(self):
         nr_headers = dict(self._generate_response_headers())
         return convert_to_cat_metadata_value(nr_headers)
 
     def process_request_metadata(self, cat_linking_value):
-        try:
-            payload = base64_decode(cat_linking_value)
-        except:
-            return
-
-        nr_headers = json_decode(payload)
-        encoded_cross_process_id = nr_headers.get('X-fast-ID')
-        encoded_txn_header = nr_headers.get('X-fast-Transaction')
-        return self._process_incoming_cat_headers(encoded_cross_process_id,
-                                                  encoded_txn_header)
+        return
 
     def set_transaction_name(self, name, group=None, priority=None):
 
@@ -1322,15 +1253,14 @@ def suppress_transaction_trace(flag=True):
 
 
 def record_custom_metric(name, value, application=None):
-   pass
+    pass
 
 
 def record_custom_metrics(metrics, application=None):
-   pass
+    pass
 
 
 def record_custom_event(event_type, params, application=None):
-
     if application is None:
         transaction = current_transaction()
         if transaction:
