@@ -15,6 +15,8 @@ from fast_tracker.api.transaction import Transaction, current_transaction
 from fast_tracker.common.async_proxy import async_proxy, TransactionContext
 from fast_tracker.common.encoding_utils import (obfuscate, json_encode,
                                                 decode_fast_header, ensure_str)
+from fast_tracker.common.utils import seq_id
+
 
 from fast_tracker.core.attribute import create_attributes, process_user_attribute
 from fast_tracker.core.attribute_filter import DST_BROWSER_MONITORING, DST_NONE
@@ -83,21 +85,6 @@ def _lookup_environ_setting(environ, name, default=False):
 
 def _parse_synthetics_header(header):
     synthetics = {}
-    version = None
-
-    try:
-        if len(header) > 0:
-            version = int(header[0])
-
-        if version == 1:
-            synthetics['version'] = version
-            synthetics['account_id'] = int(header[1])
-            synthetics['resource_id'] = header[2]
-            synthetics['job_id'] = header[3]
-            synthetics['monitor_id'] = header[4]
-    except Exception:
-        return
-
     return synthetics
 
 
@@ -149,6 +136,12 @@ class WebTransaction(Transaction):
                 k = ensure_str(k)
                 if k is not None:
                     self._request_headers[k.lower()] = v
+        tracker_id_name = self._settings.carrier_header.tracker_id_name or 'x-fast-trace-id'
+        trace_id = self._request_headers.get(tracker_id_name, '')
+        if trace_id:
+            self._trace_id = trace_id
+        else:
+            self._trace_id = seq_id()
 
         if query_string and not self._settings.high_security:
             query_string = ensure_str(query_string)
@@ -193,40 +186,12 @@ class WebTransaction(Transaction):
     def _process_synthetics_header(self):
         # Check for Synthetics header
 
-        settings = self._settings
-
-        if settings.synthetics.enabled and \
-                settings.trusted_account_ids and \
-                settings.encoding_key:
-
-            encoded_header = self._request_headers.get('x-fast-synthetics')
-            encoded_header = encoded_header and ensure_str(encoded_header)
-            if not encoded_header:
-                return
-
-            decoded_header = decode_fast_header(
-                encoded_header,
-                settings.encoding_key)
-            synthetics = _parse_synthetics_header(decoded_header)
-
-            if synthetics and \
-                    synthetics['account_id'] in \
-                    settings.trusted_account_ids:
-                self.synthetics_header = encoded_header
-                self.synthetics_resource_id = synthetics['resource_id']
-                self.synthetics_job_id = synthetics['job_id']
-                self.synthetics_monitor_id = synthetics['monitor_id']
+        pass
 
     def _process_context_headers(self):
 
         if self._settings.distributed_tracing.enabled:
             self.accept_distributed_trace_headers(self._request_headers)
-        else:
-            client_cross_process_id = \
-                self._request_headers.get('x-fast-id')
-            txn_header = self._request_headers.get('x-fast-transaction')
-            self._process_incoming_cat_headers(client_cross_process_id,
-                                               txn_header)
 
     def process_response(self, status_code, response_headers):
         if not self.enabled:
@@ -252,14 +217,8 @@ class WebTransaction(Transaction):
         except Exception:
             pass
 
-        if self.client_cross_process_id is None:
-            return []
-        try:
-            read_length = int(self._request_headers.get('content-length'))
-        except Exception:
-            read_length = -1
+        return []
 
-        return self._generate_response_headers(read_length)
 
     @property
     def agent_attributes(self):
@@ -309,114 +268,10 @@ class WebTransaction(Transaction):
         return attributes_request
 
     def browser_timing_header(self):
-        if not self.enabled:
-            return ''
-
-        if self._state != self.STATE_RUNNING:
-            return ''
-
-        if self.background_task:
-            return ''
-
-        if self.ignore_transaction:
-            return ''
-
-        if not self._settings:
-            return ''
-
-        if not self._settings.browser_monitoring.enabled:
-            return ''
-
-        if self.rum_header_generated:
-            return ''
-
-        if self._settings.js_agent_loader:
-            header = _js_agent_header_fragment % self._settings.js_agent_loader
-
-            try:
-                if six.PY2:
-                    header = header.encode('ascii')
-                else:
-                    header.encode('ascii')
-
-            except UnicodeError:
-                if not WebTransaction.unicode_error_reported:
-                    _logger.error('ASCII encoding of js-agent-header failed.',
-                                  header)
-                    WebTransaction.unicode_error_reported = True
-
-                header = ''
-
-        else:
-            header = ''
-        if header:
-            self.rum_header_generated = True
-
-        return header
+        return ''
 
     def browser_timing_footer(self):
-
-        if not self.enabled:
-            return ''
-
-        if self._state != self.STATE_RUNNING:
-            return ''
-
-        if self.ignore_transaction:
-            return ''
-
-        if not self.rum_header_generated:
-            return ''
-
-        if self.rum_footer_generated:
-            return ''
-        self._freeze_path()
-
-        obfuscation_key = self._settings.license_key[:13]
-
-        attributes = {}
-
-        user_attributes = {}
-        for attr in self.user_attributes:
-            if attr.destinations & DST_BROWSER_MONITORING:
-                user_attributes[attr.name] = attr.value
-
-        if user_attributes:
-            attributes['u'] = user_attributes
-
-        agent_attributes = {}
-        for attr in self.request_parameters_attributes:
-            if attr.destinations & DST_BROWSER_MONITORING:
-                agent_attributes[attr.name] = attr.value
-
-        if agent_attributes:
-            attributes['a'] = agent_attributes
-
-        footer_data = self.browser_monitoring_intrinsics(obfuscation_key)
-
-        if attributes:
-            attributes = obfuscate(json_encode(attributes), obfuscation_key)
-            footer_data['atts'] = attributes
-
-        footer = _js_agent_footer_fragment % json_encode(footer_data)
-
-        try:
-            if six.PY2:
-                footer = footer.encode('ascii')
-            else:
-                footer.encode('ascii')
-
-        except UnicodeError:
-            if not WebTransaction.unicode_error_reported:
-                _logger.error('ASCII encoding of js-agent-footer failed.', footer)
-                WebTransaction.unicode_error_reported = True
-
-            footer = ''
-
-        if footer:
-            self.rum_footer_generated = True
-
-        return footer
+        return ''
 
     def browser_monitoring_intrinsics(self, obfuscation_key):
         txn_name = obfuscate(self.path, obfuscation_key)
@@ -577,15 +432,6 @@ class WSGIWebTransaction(WebTransaction):
         self.rum_footer_generated = False
 
     def __exit__(self, exc, value, tb):
-        self.record_custom_metric('Python/WSGI/Input/Bytes', self._bytes_read)
-        self.record_custom_metric('Python/WSGI/Input/Time', self.read_duration)
-        self.record_custom_metric('Python/WSGI/Input/Calls/read', self._calls_read)
-        self.record_custom_metric('Python/WSGI/Input/Calls/readline', self._calls_readline)
-        self.record_custom_metric('Python/WSGI/Input/Calls/readlines', self._calls_readlines)
-        self.record_custom_metric('Python/WSGI/Output/Bytes', self._bytes_sent)
-        self.record_custom_metric('Python/WSGI/Output/Time', self.sent_duration)
-        self.record_custom_metric('Python/WSGI/Output/Calls/yield', self._calls_yield)
-        self.record_custom_metric('Python/WSGI/Output/Calls/write', self._calls_write)
 
         return super(WSGIWebTransaction, self).__exit__(exc, value, tb)
 
