@@ -461,9 +461,9 @@ def _process_app_name_setting():
     :return:
     """
     if not _settings.product_code:
-        raise fast_tracker.api.exceptions.ConfigurationError('"FastTracker"里没有没有配置ProductCode')
+        return
     if not _settings.app_code:
-        raise fast_tracker.api.exceptions.ConfigurationError('"FastTracker"里没有配置AppCode')
+        return
     name = '#'.join([_settings.product_code, _settings.app_code])
     _settings.app_name = name
 
@@ -497,20 +497,29 @@ def _reset_configuration(section, config_dict):
     :param dict config_dict: json格式的配置文件反序列化后的值
     :return:
     """
+    # 应用配置
     section_value = _map_config_default_dict(config_dict.get(section))
+    _settings.enabled = section_value.get('Enable', True)
     _settings.product_code = section_value.get('ProductCode', '')
     _settings.app_code = section_value.get('AppCode', '')
     _settings.app_key = section_value.get('AppKey', '')
+    _settings.env_code = section_value.get('EnvCode', 'prod')
+    _settings.service_name = section_value.get('ServiceName', '')
+    _settings.tenant_code = section_value.get('TenantCode', '')
 
+    # 解析日志配置
     logging_value = _map_config_default_dict(section_value.get('Logging'))
     _settings.log_file = logging_value.get('FilePath', '')
-    _settings.audit_log_file  = logging_value.get('FilePath', '')
-    _settings.log_level = _map_log_level(logging_value.get('Level', ''))
+    _settings.audit_log_file = logging_value.get('FilePath', '')
+    _settings.log_level = _map_log_level(logging_value.get('Level', 'info'))
 
     transport_value = _map_config_default_dict(section_value.get('Transport'))
-
     _settings.transport.token_server_endpoint = transport_value.get('TokenServerEndpoint', '')
-    
+
+    carrierheader_value = _map_config_default_dict(section_value.get('CarrierHeader'))
+    _settings.carrier_header.tracker_name = carrierheader_value.get('TrackerName', 'fast-tracker')
+    _settings.carrier_header.tracker_id_name = carrierheader_value.get('TrackerIdName', 'x-fast-trace-id')
+
     # 开启全链路
     _settings.span_events.enabled = True
     _settings.collect_span_events = True
@@ -518,7 +527,6 @@ def _reset_configuration(section, config_dict):
 
     _settings.error_collector.capture_events = True
     _settings.error_collector.enabled = True
-    
 
 
 def _load_configuration(config_file=None, environment=None,
@@ -579,6 +587,11 @@ def _load_configuration(config_file=None, environment=None,
         _settings.environment = environment
         _process_configuration('FastTracker:%s' % environment)
         _reset_configuration('FastTracker:%s' % environment, json_object)
+    if log_file is None:
+        log_file = _settings.log_file
+    if log_level is None:
+        log_level = _settings.log_level
+
     initialize_logging(log_file, log_level)
     _process_app_name_setting()
     _process_labels_setting()
@@ -1178,51 +1191,6 @@ def _process_module_builtin_defaults():
     _process_module_definition('xmlrpclib',
                                'fast_tracker.hooks.external_xmlrpclib')
 
-    _process_module_definition('dropbox',
-                               'fast_tracker.hooks.external_dropbox')
-
-    _process_module_definition('facepy.graph_api',
-                               'fast_tracker.hooks.external_facepy')
-
-    _process_module_definition('pysolr',
-                               'fast_tracker.hooks.datastore_pysolr',
-                               'instrument_pysolr')
-
-    _process_module_definition('solr',
-                               'fast_tracker.hooks.datastore_solrpy',
-                               'instrument_solrpy')
-
-    _process_module_definition('elasticsearch.client',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client')
-    _process_module_definition('elasticsearch.client.cat',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_cat')
-    _process_module_definition('elasticsearch.client.cluster',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_cluster')
-    _process_module_definition('elasticsearch.client.indices',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_indices')
-    _process_module_definition('elasticsearch.client.nodes',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_nodes')
-    _process_module_definition('elasticsearch.client.snapshot',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_snapshot')
-    _process_module_definition('elasticsearch.client.tasks',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_tasks')
-    _process_module_definition('elasticsearch.client.ingest',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_client_ingest')
-    _process_module_definition('elasticsearch.connection.base',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_connection_base')
-    _process_module_definition('elasticsearch.transport',
-                               'fast_tracker.hooks.datastore_elasticsearch',
-                               'instrument_elasticsearch_transport')
-
     _process_module_definition('pika.adapters',
                                'fast_tracker.hooks.messagebroker_pika',
                                'instrument_pika_adapters')
@@ -1389,14 +1357,6 @@ def _process_module_builtin_defaults():
     _process_module_definition('gearman.worker',
                                'fast_tracker.hooks.application_gearman',
                                'instrument_gearman_worker')
-
-    _process_module_definition('botocore.endpoint',
-                               'fast_tracker.hooks.external_botocore',
-                               'instrument_botocore_endpoint')
-    _process_module_definition('botocore.client',
-                               'fast_tracker.hooks.external_botocore',
-                               'instrument_botocore_client')
-
     _process_module_definition('tornado.httpserver',
                                'fast_tracker.hooks.framework_tornado',
                                'instrument_tornado_httpserver')
@@ -1502,7 +1462,6 @@ def initialize(config_file=None, environment=None, ignore_errors=None,
 
     _load_configuration(config_file, environment, ignore_errors, log_file, log_level)
     if _settings.monitor_mode or _settings.developer_mode:
-        _settings.enabled = True
         _setup_instrumentation()
         _setup_extensions()
         _setup_agent_console()
