@@ -200,6 +200,10 @@ class LogServerSettings(Settings):
     pass
 
 
+class CarrierHeaderSettings(Settings):
+    pass
+
+
 _settings = Settings()
 _settings.attributes = AttributesSettings()
 _settings.transaction_tracer = TransactionTracerSettings()
@@ -240,10 +244,15 @@ _settings.event_harvest_config.harvest_limits = \
 
 _settings.transport = TransportSettings()
 _settings.log_server = LogServerSettings()
+_settings.carrier_header = CarrierHeaderSettings()
 
 _settings.log_file = os.environ.get('FAST_LOG', 'logs/fast-tracker/{Date}.log')
 _settings.audit_log_file = os.environ.get('FAST_AUDIT_LOG', 'logs/fast-tracker/{Date}.log')
 
+# 请求头
+_settings.carrier_header.tracker_name = 'fast-tracker'
+_settings.carrier_header.tracker_id_name = 'x-fast-trace-id'
+
 
 def _environ_as_int(name, default=0):
     #  解析环境/配置文件变量为int类型
@@ -351,6 +360,7 @@ _settings.ca_bundle_path = os.environ.get('FAST_CA_BUNDLE_PATH', None)  #  CA证
 _settings.product_code = os.environ.get('FAST_PRODUCT_CODE', '')
 _settings.app_code = os.environ.get('FAST_APP_CODE', '')
 _settings.app_key = os.environ.get('FAST_APP_KEY', '')
+_settings.thread_id_max_value = 65535
 _settings.app_name = ''
 _settings.transport.token_server_endpoint = ''
 _settings.transport.queue_size = 0
@@ -418,7 +428,7 @@ _settings.attributes.enabled = True
 _settings.attributes.exclude = []
 _settings.attributes.include = []
 
-_settings.cross_application_tracer.enabled = True
+_settings.cross_application_tracer.enabled = False
 
 _settings.transaction_events.enabled = True
 _settings.transaction_events.attributes.enabled = True
