@@ -10,6 +10,7 @@ import fast_tracker.packages.six as six
 from fast_tracker.api.external_trace import ExternalTrace
 from fast_tracker.api.transaction import current_transaction
 from fast_tracker.common.object_wrapper import wrap_function_wrapper
+from fast_tracker.common.span_enum import SpanLayerAtrr, SpanType
 
 
 def _nr_wrapper_opener_director_open_(wrapped, instance, args, kwargs):
@@ -31,7 +32,7 @@ def _nr_wrapper_opener_director_open_(wrapped, instance, args, kwargs):
     if details.hostname is None:
         return wrapped(*args, **kwargs)
 
-    with ExternalTrace('urllib2', url):
+    with ExternalTrace('urllib2', url, span_type=SpanType.Exit.value, span_layer=SpanLayerAtrr.HTTP.value):
         return wrapped(*args, **kwargs)
 
 
